@@ -5,7 +5,7 @@ use Moo 1.003 ();
 use Search::Elasticsearch::Util qw(parse_params load_plugin);
 use namespace::clean;
 
-our $VERSION = '2.00';
+our $VERSION = '2.01';
 
 my %Default_Plugins = (
     client      => [ 'Search::Elasticsearch::Client',       '2_0::Direct' ],
@@ -61,7 +61,7 @@ Search::Elasticsearch - The official client for Elasticsearch
 
 =head1 VERSION
 
-version 2.00
+version 2.01
 
 =head1 SYNOPSIS
 
@@ -123,7 +123,7 @@ version 2.00
 
     $info        = $e->cluster->info;
     $health      = $e->cluster->health;
-    $node_stats  = $e->cluster->node_stats
+    $node_stats  = $e->cluster->node_stats;
 
     # Index requests:
 
@@ -138,15 +138,11 @@ itself is a flexible and powerful open source, distributed real-time
 search and analytics engine for the cloud.  You can read more about it
 on L<elastic.co|http://www.elastic.co>.
 
-=head1 BACKWARDS COMPATIBILITY AND ELASTICSEARCH 0.90.x
+=head1 BACKWARDS COMPATIBILITY
 
-This version of the client supports the Elasticsearch 1.0 branch by
-default, which is not backwards compatible with the 0.90 branch.
-
-If you need to talk to a version of Elasticsearch before 1.0.0,
-please use L<Search::Elasticsearch::Client::0_90::Direct> as follows:
-
-    $es = Search::Elasticsearch->new( client => '0_90::Direct' );
+This version of the client supports the Elasticsearch 2.0 branch by
+default, see L</Client> section below for details of working with 1.0
+and 0.90 branches.
 
 =head2 Motivation
 
@@ -655,7 +651,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
