@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Bulk;
-$Search::Elasticsearch::Bulk::VERSION = '1.99';
+$Search::Elasticsearch::Bulk::VERSION = '2.01';
 use Moo;
 with 'Search::Elasticsearch::Role::Bulk',
     'Search::Elasticsearch::Role::Is_Sync';
@@ -111,7 +111,7 @@ Search::Elasticsearch::Bulk - A helper module for the Bulk API and for reindexin
 
 =head1 VERSION
 
-version 1.99
+version 2.01
 
 =head1 SYNOPSIS
 
@@ -142,7 +142,7 @@ version 1.99
     $bulk->add_action( update => { id => 1, script => '...' });
 
     # Manual flush
-    $bulk->flush
+    $bulk->flush;
 
     # Reindex docs:
     my $bulk = $es->bulk_helper(
@@ -154,7 +154,7 @@ version 1.99
 
 =head1 DESCRIPTION
 
-This module provides a wrapper for the L<Search::Elasticsearch::Client::1_0::Direct/bulk()>
+This module provides a wrapper for the L<Search::Elasticsearch::Client::2_0::Direct/bulk()>
 method which makes it easier to run multiple create, index, update or delete
 actions in a single request. It also provides a simple interface
 for L<reindexing documents|/REINDEXING DOCUMENTS>.
@@ -198,7 +198,7 @@ Search::Elasticsearch client as the C<es> argument.
 The C<index> and C<type> parameters provide default values for
 C<index> and C<type>, which can be overridden in each action.
 You can also pass any other values which are accepted
-by the L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> method.
+by the L<bulk()|Search::Elasticsearch::Client::2_0::Direct/bulk()> method.
 
 See L</flush()> for more information about the other parameters.
 
@@ -209,7 +209,7 @@ See L</flush()> for more information about the other parameters.
     $result = $bulk->flush;
 
 The C<flush()> method sends all buffered actions to Elasticsearch using
-a L<bulk()|Search::Elasticsearch::Client::1_0::Direct/bulk()> request.
+a L<bulk()|Search::Elasticsearch::Client::2_0::Direct/bulk()> request.
 
 =head2 Auto-flushing
 
@@ -373,7 +373,7 @@ they must be specified either in L</new()> or in every action.
     );
 
 The C<create()> helper method allows you to add multiple C<create> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/create()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/create()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -399,7 +399,7 @@ you can just pass the individual document bodies.
     );
 
 The C<index()> helper method allows you to add multiple C<index> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/index()>
+It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/index()>
 except that the document body should be passed as the C<source> or C<_source>
 parameter, instead of as C<body>.
 
@@ -412,7 +412,7 @@ parameter, instead of as C<body>.
     );
 
 The C<delete()> helper method allows you to add multiple C<delete> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/delete()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/delete()>.
 
 =head2 C<delete_ids()>
 
@@ -431,18 +431,17 @@ In this case, all you have to do is to pass in a list of IDs.
         },
         { id            => 2,
           lang          => 'mvel',
-          script        => '_ctx.source.counter+=incr',
-          params        => { incr => 1},
+          script        => { script }
           upsert        => { upsert doc }
         },
         ...
     );
 
 The C<update()> helper method allows you to add multiple C<update> actions.
-It accepts the same parameters as L<Search::Elasticsearch::Client::1_0::Direct/update()>.
+It accepts the same parameters as L<Search::Elasticsearch::Client::2_0::Direct/update()>.
 An update can either use a I<partial doc> which gets merged with an existing
 doc (example 1 above), or can use a C<script> to update an existing doc
-(example 2 above).
+(example 2 above). More information on C<script> can be found here: L<Search::Elasticsearch::Client::2_0::Direct/update()>.
 
 =head1 REINDEXING DOCUMENTS
 
@@ -529,7 +528,7 @@ another, you can use two separate C<$es> objects:
     $es_target  = Search::Elasticsearch->new( nodes => 'localhost:9200' );
     $es_source  = Search::Elasticsearch->new( nodes => 'search1:9200' );
 
-    my $bulk = $es_targer->bulk_helper(
+    my $bulk = $es_targert->bulk_helper(
         verbose => 1
     )
     -> reindex(
@@ -600,7 +599,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
