@@ -1,7 +1,5 @@
 package Search::Elasticsearch::Error;
-$Search::Elasticsearch::Error::VERSION = '1.99';
-use Moo;
-
+$Search::Elasticsearch::Error::VERSION = '2.01';
 our $DEBUG = 0;
 
 @Search::Elasticsearch::Error::Internal::ISA     = __PACKAGE__;
@@ -9,6 +7,7 @@ our $DEBUG = 0;
 @Search::Elasticsearch::Error::NoNodes::ISA      = __PACKAGE__;
 @Search::Elasticsearch::Error::Unauthorized::ISA = __PACKAGE__;
 @Search::Elasticsearch::Error::Forbidden::ISA    = __PACKAGE__;
+@Search::Elasticsearch::Error::Illegal::ISA      = __PACKAGE__;
 @Search::Elasticsearch::Error::Request::ISA      = __PACKAGE__;
 @Search::Elasticsearch::Error::Timeout::ISA      = __PACKAGE__;
 @Search::Elasticsearch::Error::Cxn::ISA          = __PACKAGE__;
@@ -152,6 +151,13 @@ sub stacktrace {
 
     return $o .= ( '-' x 80 ) . "\n";
 }
+
+#===================================
+sub TO_JSON {
+#===================================
+    my $self = shift;
+    return $self->_stringify;
+}
 1;
 
 # ABSTRACT: Errors thrown by Search::Elasticsearch
@@ -168,7 +174,7 @@ Search::Elasticsearch::Error - Errors thrown by Search::Elasticsearch
 
 =head1 VERSION
 
-version 1.99
+version 2.01
 
 =head1 DESCRIPTION
 
@@ -186,6 +192,10 @@ consists of the following:
 The C<$Search::Elasticsearch::Error::DEBUG> variable can be set to C<1> or C<2>
 to increase the verbosity of errors.
 
+Error objects stringify to a human readable error message when used in text
+context (for example: C<print 'Oh no! '.$error>).  They also support the C<TO_JSON>
+method to support conversion to JSON when L<JSON/convert_blessed> is enabled.
+
 =head1 ERROR CLASSES
 
 The following error classes are defined:
@@ -268,6 +278,12 @@ blocking, eg there are not enough master nodes to form a cluster, or
 because the authenticated user is trying to perform an unauthorized
 action. This error is triggered by the C<403> HTTP status code.
 
+=item * C<Search::Elasticsearch::Error::Illegal>
+
+You have attempted to perform an illegal operation.
+For instance, you attempted to use a Scroll helper in a different process
+after forking.
+
 =item * C<Search::Elasticsearch::Error::Serializer>
 
 There was an error serializing a variable or deserializing a string.
@@ -285,7 +301,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
