@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Bulk;
-$Search::Elasticsearch::Role::Bulk::VERSION = '1.99';
+$Search::Elasticsearch::Role::Bulk::VERSION = '2.01';
 use Moo::Role;
 requires 'add_action', 'flush';
 
@@ -104,7 +104,7 @@ sub delete_ids {
 }
 
 our @Update_Params = qw(
-    doc upsert doc_as_upsert scripted_upsert
+    doc upsert doc_as_upsert fields scripted_upsert
     script script_id script_file
     params lang detect_noop
 );
@@ -284,7 +284,7 @@ Search::Elasticsearch::Role::Bulk - Provides common functionality to L<Elasticse
 
 =head1 VERSION
 
-version 1.99
+version 2.01
 
 =head1 AUTHOR
 
@@ -292,7 +292,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
