@@ -1,5 +1,5 @@
 package Search::Elasticsearch::Role::Client::Direct::Main;
-$Search::Elasticsearch::Role::Client::Direct::Main::VERSION = '1.99';
+$Search::Elasticsearch::Role::Client::Direct::Main::VERSION = '2.01';
 use Moo::Role;
 requires '_namespace';
 
@@ -10,6 +10,7 @@ has 'nodes'               => ( is => 'lazy', init_arg => undef );
 has 'indices'             => ( is => 'lazy', init_arg => undef );
 has 'snapshot'            => ( is => 'lazy', init_arg => undef );
 has 'cat'                 => ( is => 'lazy', init_arg => undef );
+has 'tasks'               => ( is => 'lazy', init_arg => undef );
 has 'bulk_helper_class'   => ( is => 'ro',   default  => 'Bulk' );
 has 'scroll_helper_class' => ( is => 'ro',   default  => 'Scroll' );
 has '_bulk_class'         => ( is => 'lazy' );
@@ -69,6 +70,7 @@ sub _build_nodes    { shift->_build_namespace('Nodes') }
 sub _build_indices  { shift->_build_namespace('Indices') }
 sub _build_snapshot { shift->_build_namespace('Snapshot') }
 sub _build_cat      { shift->_build_namespace('Cat') }
+sub _build_tasks    { shift->_build_namespace('Tasks') }
 #===================================
 
 #===================================
@@ -95,7 +97,7 @@ Search::Elasticsearch::Role::Client::Direct::Main - Attributes and methods used
 
 =head1 VERSION
 
-version 1.99
+version 2.01
 
 =head1 DESCRIPTION
 
@@ -109,7 +111,7 @@ Clinton Gormley <drtech@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Elasticsearch BV.
+This software is Copyright (c) 2016 by Elasticsearch BV.
 
 This is free software, licensed under:
 
